referrerpolicy=no-referrer-when-downgrade

set_hrmp_channel_max_message_size

Function set_hrmp_channel_max_message_size 

pub fn set_hrmp_channel_max_message_size<T: Config>(new: u32)
Sets the maximum size of a message that could ever be put into an HRMP channel.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::set_hrmp_channel_max_message_size.