referrerpolicy=no-referrer-when-downgrade

set_hrmp_channel_max_total_size

Function set_hrmp_channel_max_total_size 

pub fn set_hrmp_channel_max_total_size<T: Config>(new: u32)
Sets the maximum total size of messages in bytes allowed in an HRMP channel at once.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::set_hrmp_channel_max_total_size.