referrerpolicy=no-referrer-when-downgrade

set_max_upward_message_size

Function set_max_upward_message_size 

pub fn set_max_upward_message_size<T: Config>(new: u32)
Sets the maximum size of an upward message that can be sent by a candidate.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::set_max_upward_message_size.