referrerpolicy=no-referrer-when-downgrade

set_max_upward_queue_size

Function set_max_upward_queue_size 

pub fn set_max_upward_queue_size<T: Config>(new: u32)
Sets the maximum total size of items that can present in a upward dispatch queue at once.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::set_max_upward_queue_size.