referrerpolicy=no-referrer-when-downgrade

set_max_validators_per_core

Function set_max_validators_per_core 

pub fn set_max_validators_per_core<T: Config>(new: Option<u32>)
Set the maximum number of validators to assign to any core.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::set_max_validators_per_core.